FormatError

Enum FormatError 

pub enum FormatError {
    SyntaxError {
        message: &'static str,
    },
    RangeError {
        input: TextRange,
        tree: TextRange,
    },
    InvalidDocument(InvalidDocumentError),
    PoorLayout,
}
Series of errors encountered during formatting

Variants



SyntaxError

In case a node can’t be formatted because it either misses a require child element or a child is present that should not (e.g. a trailing comma after a rest element).

Fields

message: &'static str


RangeError

In case range formatting failed because the provided range was larger than the formatted syntax tree

Fields



InvalidDocument(InvalidDocumentError)

In case printing the document failed because it has an invalid structure.



PoorLayout

Formatting failed because some content encountered a situation where a layout choice by an enclosing crate::Format resulted in a poor layout for a child crate::Format.

It’s up to an enclosing crate::Format to handle the error and pick another layout. This error should not be raised if there’s no outer crate::Format handling the poor layout error, avoiding that formatting of the whole document fails.

Implementations

Source

impl FormatError

pub fn syntax_error(message: &'static str) -> Self