Arguments

Struct Arguments 

pub struct Arguments<'fmt, Context>(pub &'fmt [Argument<'fmt, Context>]);
Sequence of objects that should be formatted in the specified order.

The format_args! macro will safely create an instance of this structure.

You can use the Arguments<a> that format_args! return in Format context as seen below. It will call the format function for each of its objects.

use ruff_formatter::prelude::*;
use ruff_formatter::{format, format_args};

let formatted = format!(SimpleFormatContext::default(), [
    format_args!(token("a"), space(), token("b"))
])?;

assert_eq!("a b", formatted.print()?.as_code());

Tuple Fields

0: &'fmt [Argument<'fmt, Context>]