pub struct SourceCodeSlice { /* private fields */ }Expand description
A slice into the source text of a document.
It only stores the range in production builds for a more compact representation, but it keeps the original text in debug builds for better developer experience.
Implementations
Sourceimpl SourceCodeSlice
impl SourceCodeSlice
Sourcepub fn text<'a>(&self, code: SourceCode<'a>) -> &'a str
pub fn text<'a>(&self, code: SourceCode<'a>) -> &'a str
Returns the slice’s text.